==> huazhi-article-1.3.8.tgz: package/entry/webview.js <==
import Parse from '../parse';
import { addEvent } from '../helpers';
import { tap } from '../events';

const ACTIONS_TYPE = {
  OPEN_IMAGE: 'OPEN_IMAGE',
  CLICK_BLANK: 'CLICK_BLANK',
  ROUTE: 'ROUTE'
};

class WebviewRich extends Parse {
  constructor(option = { platform: 'webview' }) {
    super(option);
    this.lazyLoad = true;
    this.bridge = window.bridge;
    this.images = [];
    this.imagesDoc = null;
    this.clientHeight = 0;
  }

  initEvents() {
    tap(document.body, event => {
      event.stopPropagation();
      const { target } = event;
      const e = target.getAttribute('e');

      // 图片
      if (e === 'image') {
        const index = +target.getAttribute('index');
        this.bridge.send(ACTIONS_TYPE.OPEN_IMAGE, {
          index: index,
          images: this.images
        });

        // 跳转
      } else if (e === 'link') {
        let route = JSON.parse(target.dataset.href);
        this.bridge.send(ACTIONS_TYPE.ROUTE, {
            ...route
        });

        // 空白
      } else {
        this.bridge.send(ACTIONS_TYPE.CLICK_BLANK, {});
      }
    });
  }

  renderImage(props, attrs) {
    let { width, height } = props;
    let imgWidth = Math.floor(window.screen.width * 0.817);
    const paddingTop = width < imgWidth ? height + 'px' : (height / width) * 100 + '%';

    this.images.push(props);

    const showDesc = props.desc && props.desc !== '';

    return `<div><div><div style="padding-top: ${paddingTop}"></div><img e="image" index=${
      attrs.index
    } data-src=${props.url}></div>${
      showDesc ? `<span>${props.desc}</span>` : ''
    } </div>`;
  }

  renderLink(props) {
    let str = JSON.stringify(props.route);
    return `<a href="javascript:void(0)" e="link" data-href=${str} target="_blank">${props.content}</a>`;
  }

  renderVideo(props) {
    return `<video src="${props.url}" controls="true"></video>`;
  }
}

export default WebviewRich;

==> huazhi-article-1.4.5.tgz: package/entry/webview.js <==
import Parse from '../parse';
import {addEvent, computedImageSize} from '../helpers';
import { tap } from '../events';

const ACTIONS_TYPE = {
  OPEN_IMAGE: 'OPEN_IMAGE',
  CLICK_BLANK: 'CLICK_BLANK',
  ROUTE: 'ROUTE'
};

class WebviewRich extends Parse {
  constructor(option = { platform: 'webview' }) {
    super(option);
    this.lazyLoad = false;
    this.bridge = window.bridge;
    this.images = [];
    this.imagesDoc = null;
    this.clientHeight = 0;
  }

  initEvents() {
    tap(document.body, event => {
      event.stopPropagation();
      const { target } = event;
      const e = target.getAttribute('e');

      // 图片
      if (e === 'image') {
        const index = +target.getAttribute('index');
        this.bridge.send(ACTIONS_TYPE.OPEN_IMAGE, {
          index: index,
          images: this.images
        });

        // 跳转
      } else if (e === 'link') {
        let route = JSON.parse(target.dataset.href);
        this.bridge.send(ACTIONS_TYPE.ROUTE, {
            ...route
        });

        // 空白
      } else {
        this.bridge.send(ACTIONS_TYPE.CLICK_BLANK, {});
      }
    });
  }

  renderImage(props, attrs) {
    let { width, height } = props;
    let imgWidth = Math.floor(window.screen.width * 0.817);
    const paddingTop = width < imgWidth ? height + 'px' : (height / width) * 100 + '%';

    this.images.push(props);

    const showDesc = props.desc && props.desc !== '';

    let element = showDesc ? `<div><div><div></div><img e="image" index=${
        attrs.index
        } data-src=${props.url} src=${props.url}></div><span>${props.desc}</span></div>`
        : `<div><div><div></div><img e="image" index=${
            attrs.index
            } data-src=${props.url} src=${props.url}></div></div>`;

    return element;
  }

  renderLink(props) {
    let str = JSON.stringify(props.route);
    return `<a href="javascript:void(0)" e="link" data-href=${str} target="_blank">${props.content}</a>`;
  }

  renderVideo(props) {
    return `<video src="${props.url}" controls="controls"></video>`;
  }
}

export default WebviewRich;
